Level class

Level

Implemented types

Constructors

Level(String name, int value)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
Unique value for this level. Used to order levels, so filtering can exclude messages whose level is under certain value.
final

Methods

compareTo(Level other) int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator <(Level other) bool
operator <=(Level other) bool
operator ==(Object other) bool
The equality operator.
override
operator >(Level other) bool
operator >=(Level other) bool

Constants

ALL → const Level
Special key to turn on logging for all levels (value = 0).
DEBUG → const Level
Key for highly detailed tracing .
ERROR → const Level
Key for error messages
INFO → const Level
Key for informational messages
OFF → const Level
Special key to turn off all logging (value = 2000).
SERIOUS → const Level
Key for serious error problems.
WARNING → const Level
Key for potential problems .