Logger class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

minLevel Level
set the log level.
no getter

Static Methods

debug(Object? message) → void
error(Object? message) → void
info(Object? message) → void
serious(Object? message) → void
setEngines(List<Output> engines) → void
custom log engines.
warning(Object? message) → void