LogRecord class
A log entry representation used to propagate information from Logger to individual handlers.
Constructors
- LogRecord({required Level level, required String message, required StackTrace stackTrace, Object? object})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → Level
-
final
- lineNumber ↔ int
-
getter/setter pair
- message → String
-
final
- object → Object?
-
Non-string message passed to Logger.
final
- path ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace
-
Associated stackTrace (if any) when recording errors messages.
final
- time → DateTime
-
Time when this record was created.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited